@@ -13,11 +13,13 @@
 
 
 // TODO: throw out stop_codons: "TAG", "TAA", "TGA"
+// TODO: read in partition file, edit and write out
 
 void print_help ();
 std::string get_version_line ();
 
 void print_help () {
+    std::cout << std::endl;
     std::cout << "Clean alignments by removing positions/taxa with too much ambiguous data." << std::endl;
     std::cout << "This will take fasta, fastq, phylip, and nexus formats from a file or STDIN." << std::endl;
     std::cout << "Results are written in fasta format." << std::endl;
@@ -27,6 +29,9 @@ void print_help () {
     std::cout << "Options:" << std::endl;
     std::cout << " -s, --seqf=FILE     input sequence file, STDIN otherwise" << std::endl;
     std::cout << " -p, --prop=DOUBLE   proportion required to be present, default=0.5" << std::endl;
+    std::cout << " -e, --empty         remove columns that are completely empty (- or ?)" << std::endl;
+    std::cout << " -m, --min=INT       the minimum number of good characters required per site" << std::endl;
+    std::cout << "                       - a min of 1 is equivalent to -e above" << std::endl;
     std::cout << " -t, --taxa          consider missing data per taxon (default: per site)" << std::endl;
     std::cout << " -c, --codon         examine sequences by codon rather than site" << std::endl;
     std::cout << "                       - requires all sequences be in frame and of correct length" << std::endl;
@@ -56,6 +61,8 @@ static struct option const long_options[] =
     {"seqf", required_argument, nullptr, 's'},
     {"outf", required_argument, nullptr, 'o'},
     {"prop", required_argument, nullptr, 'p'},
+    {"empty", no_argument, nullptr, 'e'},
+    {"min", required_argument, nullptr, 'm'},
     {"taxa", required_argument, nullptr, 't'},
     {"codon", required_argument, nullptr, 'c'},
     {"info", required_argument, nullptr, 'i'},
@@ -79,10 +86,12 @@ int main(int argc, char * argv[]) {
     bool by_taxon = false;
     bool by_codon = false;
     bool count_only = false;
+    bool remove_empty = false;
+    int min_chars = 0;
 
     while (true) {
         int oi = -1;
-        int c = getopt_long(argc, argv, "s:o:p:atcivhVC", long_options, &oi);
+        int c = getopt_long(argc, argv, "s:o:p:em:atcivhVC", long_options, &oi);
         if (c == -1) {
             break;
         }
@@ -104,6 +113,12 @@ int main(int argc, char * argv[]) {
                     exit(0);
                 }
                 break;
+            case 'e':
+                remove_empty = true;
+                break;
+            case 'm':
+                min_chars = string_to_int(optarg, "-m");;
+                break;
             case 't':
                 by_taxon = true;
                 break;
@@ -157,7 +172,8 @@ int main(int argc, char * argv[]) {
         }
     }
     
-    SequenceCleaner SC(pios, prop_required, by_taxon, by_codon, count_only, verbose);
+    SequenceCleaner SC(pios, prop_required, remove_empty, min_chars, by_taxon,
+            by_codon, count_only, verbose);
     
     // write sequences. currently only fasta format.
     if (!count_only) {
