@@ -23,6 +23,7 @@ void print_help ();
 std::string get_version_line ();
 
 void print_help () {
+    std::cout << std::endl;
     std::cout << "Continuous character rate estimation with Brownian and OU." << std::endl;
     std::cout << "This will take fasta, phylip, and nexus formats from a file or STDIN." << std::endl;
     std::cout << std::endl;
@@ -128,6 +129,16 @@ int main(int argc, char * argv[]) {
         poos = tfstr;
     } else {
         poos = &std::cin;
+        if (!check_for_input_to_stream()) {
+            // if both inputs missing: print help
+            if (!cfileset) {
+                print_help();
+                exit(1);
+            } else {
+                std::cerr << "Error: missing required tree input. Exiting." << std::endl;
+                exit(1);
+            }
+        }
     }
 
     if (cfileset) {
