@@ -16,6 +16,7 @@ void print_help ();
 std::string get_version_line ();
 
 void print_help () {
+    std::cout << std::endl;
     std::cout << "MCMC log file manipulator." << std::endl;
     std::cout << "Can combine and resample parameters or trees across files." << std::endl;
     std::cout << "Log files need not contain the same number of samples." << std::endl;
@@ -100,6 +101,7 @@ int main(int argc, char * argv[]) {
     std::string incolids;
     std::string logtype;
     char * outf = nullptr;
+    bool argspresent = false;
     
     while (true) {
         int oi = -1;
@@ -130,6 +132,7 @@ int main(int argc, char * argv[]) {
                     }
                 }
                 logtype = "parameter";
+                argspresent = true;
                 break;
             case 't':
                 tfileset = true;
@@ -152,10 +155,12 @@ int main(int argc, char * argv[]) {
                     }
                 }
                 logtype = "tree";
+                argspresent = true;
                 break;
             case 'o':
                 outfileset = true;
                 outf = strdup(optarg);
+                argspresent = true;
                 break;
             case 'b':
                 burnin = string_to_int(optarg, "-b");
@@ -163,6 +168,7 @@ int main(int argc, char * argv[]) {
                     std::cerr << "Error: burnin must be a positive integer. Exiting." << std::endl;
                     exit(0);
                 }
+                argspresent = true;
                 break;
             case 'n':
                 nthin = string_to_int(optarg, "-n");
@@ -170,36 +176,45 @@ int main(int argc, char * argv[]) {
                     std::cerr << "Error: nthin must be a >= 1. Exiting." << std::endl;
                     exit(0);
                 }
+                argspresent = true;
                 break;
             case 'r':
                 nrandom = string_to_int(optarg, "-r");
+                argspresent = true;
                 break;
             case 'i':
                 count = true;
+                argspresent = true;
                 break;
             case 's':
                 summarize = true;
+                argspresent = true;
                 break;
             case 'c':
                 get_columns = true;
+                argspresent = true;
                 break;
             case 'd':
                 delete_columns = true;
                 incolids = strdup(optarg);
                 parse_comma_list(incolids, col_indices);
                 sort(col_indices.begin(), col_indices.end());
+                argspresent = true;
                 break;
             case 'k':
                 keep_columns = true;
                 incolids = strdup(optarg);
                 parse_comma_list(incolids, col_indices);
                 sort(col_indices.begin(), col_indices.end());
+                argspresent = true;
                 break;
             case 'x':
                 seed = string_to_long_int(optarg, "-x");
+                argspresent = true;
                 break;
             case 'v':
                 verbose = true;
+                argspresent = true;
                 break;
             case 'h':
                 print_help();
@@ -216,6 +231,11 @@ int main(int argc, char * argv[]) {
         }
     }
     
+    if (!argspresent) {
+        print_help();
+        exit(1);
+    }
+    
     std::ostream * poos = nullptr;
     std::ofstream * ofstr = nullptr;
     
