@@ -19,6 +19,7 @@ void print_help ();
 std::string get_version_line ();
 
 void print_help () {
+    std::cout << std::endl;
     std::cout << "This will trace a big tree given a taxon list and and produce newick." << std::endl;
     std::cout << "Data can be read from a file or STDIN." << std::endl;
     std::cout << std::endl;
@@ -123,6 +124,27 @@ int main(int argc, char * argv[]) {
         }
     }
     
+    std::istream * pios = nullptr;
+    std::ostream * poos = nullptr;
+    std::ifstream * fstr = nullptr;
+    std::ofstream * ofstr = nullptr;
+    
+    if (fileset) {
+        fstr = new std::ifstream(treef);
+        pios = fstr;
+    } else {
+        pios = &std::cin;
+        if (!check_for_input_to_stream()) {
+            if (!namesset && !namefileset && !outfileset) {
+                print_help();
+                exit(1);
+            } else {std::cout << "Error: missing required tree input. Exiting."
+                    << std::endl;
+                exit(1);
+            }
+        }
+    }
+    
     if (fileset && outfileset) {
         check_inout_streams_identical(treef, outf);
     }
@@ -151,21 +173,6 @@ int main(int argc, char * argv[]) {
         exit(0);
     }
 
-    std::istream * pios = nullptr;
-    std::ostream * poos = nullptr;
-    std::ifstream * fstr = nullptr;
-    std::ofstream * ofstr = nullptr;
-    
-    if (fileset) {
-        fstr = new std::ifstream(treef);
-        pios = fstr;
-    } else {
-        pios = &std::cin;
-        if (!check_for_input_to_stream()) {
-            print_help();
-            exit(1);
-        }
-    }
     if (outfileset) {
         ofstr = new std::ofstream(outf);
         poos = ofstr;
