@@ -17,6 +17,7 @@ void print_help ();
 std::string get_version_line ();
 
 void print_help () {
+    std::cout << std::endl;
     std::cout << "Tree rescaling by providing either scaling factor or root height." << std::endl;
     std::cout << "This will take a newick- or nexus-formatted tree from a file or STDIN." << std::endl;
     std::cout << "Output is written in newick format." << std::endl;
@@ -117,6 +118,23 @@ int main(int argc, char * argv[]) {
     std::ifstream * fstr = nullptr;
     std::ofstream * ofstr = nullptr;
     
+    if (tfileset) {
+        fstr = new std::ifstream(treef);
+        pios = fstr;
+    } else {
+        pios = &std::cin;
+        if (!check_for_input_to_stream()) {
+            if (!heightset && !scaleset) {
+                print_help();
+                exit(1);
+            } else {
+                std::cerr << "Error: missing tree input. Exiting."
+                << std::endl;
+                exit(1);
+            }
+        }
+    }
+    
     if (heightset && scaleset) {
         std::cerr << "Error: supply only rootheight (-r) or scale (-s), not both. Exiting."
                 << std::endl;
@@ -128,16 +146,6 @@ int main(int argc, char * argv[]) {
         exit(0);
     }
     
-    if (tfileset) {
-        fstr = new std::ifstream(treef);
-        pios = fstr;
-    } else {
-        pios = &std::cin;
-        if (!check_for_input_to_stream()) {
-            print_help();
-            exit(1);
-        }
-    }
     if (outfileset) {
         ofstr = new std::ofstream(outf);
         poos = ofstr;
