@@ -1,26 +1,25 @@
-
-
 #include "tscale.h"
 #include "tree.h"
 #include "utils.h"
 #include "tree_utils.h"
 
-using namespace std;
 
-TScale::TScale () {
-    
+TScale::TScale ():scalef_(0.0), rootheight_(0.0), rootset_(false) {
 }
 
-void TScale::set_scalef (double const& scalef) {
+
+void TScale::set_scalef (const double& scalef) {
     scalef_ = scalef;
     rootset_ = false;
 }
+ 
 
-void TScale::set_rootheight (double const& rootheight) {
+void TScale::set_rootheight (const double& rootheight) {
     rootheight_ = rootheight;
     rootset_ = true;
 }
 
+
 void TScale::rescale (Tree * tr) {
     if (rootset_) {
         // need to figure out scaling factor from original and desired root ages
