@@ -13,6 +13,7 @@
 #include <chrono>
 #include <poll.h>
 #include <unistd.h>
+#include <regex>
 
 #include "utils.h"
 #include "superdouble.h"
@@ -815,6 +816,24 @@ bool check_for_input_to_stream () {
 }
 
 
+// do strings statr/end with suffix?!?
+bool ends_with (const std::string& str, const std::string& suffix) {
+    return str.size() >= suffix.size() && 0 == str.compare(str.size()-suffix.size(), suffix.size(), suffix);
+}
+
+
+bool starts_with (const std::string& str, const std::string& prefix) {
+    return str.size() >= prefix.size() && 0 == str.compare(0, prefix.size(), prefix);
+}
+
+
+void remove_last_N (std::string &str, const long unsigned int& n) {
+    if (str.length() < n) {
+        return;
+    }
+    str.erase(str.length() - n);
+}
+
 // not using right now
 // return elements in a *not* found in b
 std::vector<std::string> get_complement (std::vector<std::string>& a, std::vector<std::string>& b) {
@@ -871,3 +890,16 @@ std::vector<std::string> regex_search_labels (const std::vector<std::string>& na
     }
     return results;
 }
+
+
+// not currently used
+std::vector<std::string> regex_replace_labels (const std::vector<std::string>& names,
+        const std::string& pattern, const std::string& replacetext) {
+    std::vector<std::string> results;
+    const std::regex regexp(pattern);
+    for (const auto & name : names) {
+        std::string res = std::regex_replace(name, regexp, replacetext);
+        //std::cout << name << ": " << std::regex_search(name, regexp) << std::endl;
+    }
+    return results;
+}
